| SEIR_prob | R Documentation |
Computes the transition pobabilities of an SIR process using the bivariate birth process representation
SEIR_prob(
t,
alpha,
beta,
kappa,
S0,
E0,
I0,
nSE,
nEI,
nIR,
direction = c("Forward", "Backward"),
nblocks = 20,
tol = 1e-12,
computeMode = 0,
nThreads = 4
)
t |
time |
alpha |
removal rate |
beta |
infection rate |
kappa |
rate at which an exposed person becomes infective |
S0 |
initial susceptible population |
E0 |
initial exposed population |
I0 |
initial infectious population |
nSE |
number of infection events |
nEI |
number of events at which an exposed person becomes infective |
nIR |
number of removal events |
direction |
direction of the transition probabilities (either |
nblocks |
number of blocks |
tol |
tolerance |
computeMode |
computation mode |
nThreads |
number of threads |
a matrix of the transition probabilities
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.